@@ -15,7 +15,7 @@ from typing import Any, Protocol
 
 import cloudpickle
 
-from shared_memory_lock import SharedMemoryLock
+from shared_memory_lock import SharedMemoryLock, SharedMemoryMutex
 
 # Queue layout in shared memory:
 # [head: u64][tail: u64][capacity: u64][item_size: u64][data...]
@@ -66,15 +66,16 @@ class SharedMemoryQueue:
             capacity: Maximum number of items the queue can hold
             item_size: Maximum size of each serialized item in bytes
             run_id: Run identifier for namespacing
-            lock: Ignored - SharedMemoryLock is always used
+            lock: Ignored - SharedMemoryMutex (Linux) or SharedMemoryLock (fallback) is used
         """
         self.name = name
         self.run_id = run_id
         self.capacity = capacity
         self.item_size = item_size
 
-        # Create or connect to shared memory lock
-        self._lock = SharedMemoryLock(name=f"{name}_queue_lock", create=create, run_id=run_id)
+        # Use SharedMemoryMutex (efficient futex-based blocking)
+        self._lock = SharedMemoryMutex(name=f"{name}_queue_lock", create=create, run_id=run_id)
+        self._lock_type = "mutex"
 
         # Calculate total size needed
         data_size = capacity * item_size
@@ -598,8 +599,9 @@ class SharedMemoryQueue:
         self.capacity = state["capacity"]
         self.item_size = state["item_size"]
 
-        # Reconnect to the same shared memory lock
-        self._lock = SharedMemoryLock(name=f"{self.name}_queue_lock", create=False, run_id=self.run_id)
+        # Reconnect to the same shared memory mutex
+        self._lock = SharedMemoryMutex(name=f"{self.name}_queue_lock", create=False, run_id=self.run_id)
+        self._lock_type = "mutex"
 
         # Reconnect to existing shared memory
         shm_name = f"{self.run_id}-{self.name}-queue" if self.run_id else f"{self.name}-queue"
